# Form Library Stress Test

This page contains iframes with forms from various libraries to stress test form autofill capabilities.
VIEW SOURCE CODE: https://github.com/billy-enrizky/openbrowser-ai

## Vanilla HTML + JS

## jQuery + Bootstrap + Select2

## AngularJS (v1)

## Angular (v2+)

## React Hook Form

## Formik (React)

## Svelte (Svelte Forms Lib)

## Ember (ember-changeset-validations)

## Vue.js (Vuelidate)

## Material UI Forms

## Wufoo (Hard to Autofill)

## Shadow DOM Form

## Dynamic Form

## Progressive Form

## React Native Web

## Nested Iframes

## Hidden Labels

## Non-Latin Form

## Contenteditable Form

## Rich Text Fields

## Table-based Form

## Animated Form

## Internationalized Form